==> narui_widgets-0.1.0.crate: narui_widgets-0.1.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

## 0.1.0 (2021-11-19)

Initial release!

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 30 commits contributed to the release over the course of 83 calendar days.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`dc18edd`](https://github.comgit//apertus-open-source-cinema/narui/commit/dc18edd7b636abfd9815716d9a3b0d297f2179e9))
    - Release freelist v0.1.0, rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`5b90685`](https://github.comgit//apertus-open-source-cinema/narui/commit/5b9068543940621cf046f0dbd8d84cad0b9bfa3d))
    - Release freelist v0.1.0, rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`974b403`](https://github.comgit//apertus-open-source-cinema/narui/commit/974b40366ec6bcd43a6c32883f117b7ca45753d8))
    - Release freelist v0.1.0, rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`86eb164`](https://github.comgit//apertus-open-source-cinema/narui/commit/86eb1640fe543d25e0e8842181aac6e9b392fe63))
    - add metadata to Cargo.toml files ([`23cb406`](https://github.comgit//apertus-open-source-cinema/narui/commit/23cb406809d31613caa3457eaa983e81b349eab6))
    - upgrade vulkano rs to 0.26.0 ([`30a2797`](https://github.comgit//apertus-open-source-cinema/narui/commit/30a2797815ef0b1ca38e782a8387c816732de1a4))
    - Rework macro imports ([`99bffa7`](https://github.comgit//apertus-open-source-cinema/narui/commit/99bffa76b373f2191ee2e50d425642905708961d))
    - Implement subpasses ([`a60d2d6`](https://github.comgit//apertus-open-source-cinema/narui/commit/a60d2d66b18ce49a05ec3e6491592f04de2e6e39))
    - formal-function-parameter-attributes for defaults ([`cd29c94`](https://github.comgit//apertus-open-source-cinema/narui/commit/cd29c94eb1ee3de66a78acdd3fbc0014880bd648))
    - implement correct (render) sorting for text ([`1aa92c5`](https://github.comgit//apertus-open-source-cinema/narui/commit/1aa92c534b1ef55750e7002d84a1da81ab413fdc))
    - render lyon, text and rounded rect single pass ([`4ad6232`](https://github.comgit//apertus-open-source-cinema/narui/commit/4ad623252ed3c4bbeccdc74a7ecd6d6cf77981fa))
    - cleanup too verbose types in narui_widgets ([`5dc288e`](https://github.comgit//apertus-open-source-cinema/narui/commit/5dc288eafdbf0e89c629f0cb376564519b1f5b12))
    - refactoring ([`16f0955`](https://github.comgit//apertus-open-source-cinema/narui/commit/16f0955fc104936fc29627c6bb29567e73ebe664))
    - optimize rect a bit, bring back circle_bench to rect_leaf ([`be5b9a1`](https://github.comgit//apertus-open-source-cinema/narui/commit/be5b9a16ef2eb8cd664af98b8b31c28e8d5a7ed2))
    - fix stroked rects ([`f62f964`](https://github.comgit//apertus-open-source-cinema/narui/commit/f62f9648833cf0df76ab33de65574ce62b1e44be))
    - integrate external hook count into FragmentStore ([`91d395e`](https://github.comgit//apertus-open-source-cinema/narui/commit/91d395ea042ca5d58aa37c85e6483f284473205a))
    - widget updates ([`cfa94f4`](https://github.comgit//apertus-open-source-cinema/narui/commit/cfa94f4f1694d2d78b2aa1d0494fb7da07744915))
    - change ergonomics of rect and input ([`0d4c5dc`](https://github.comgit//apertus-open-source-cinema/narui/commit/0d4c5dc333c5fb2fa24d88cbd2342c6d2aecc154))
    - clippy + fmt ([`43c7710`](https://github.comgit//apertus-open-source-cinema/narui/commit/43c7710aa9b8bb07dd40de75b8b2343ad9f86d28))
    - rework fragments to be stored in a FreeList besides their args ([`4ff7e6d`](https://github.comgit//apertus-open-source-cinema/narui/commit/4ff7e6d1bef469e0517888aa86dc0c1b1a867fbb))
    - Add support for clipping ([`c8867dd`](https://github.comgit//apertus-open-source-cinema/narui/commit/c8867dd0bce4633ab487b2125c00d8d16d2521cb))
    - implement depth testing, rework stack ([`5eba0e0`](https://github.comgit//apertus-open-source-cinema/narui/commit/5eba0e08724975a5a6525c3c6183553a697df2a2))
    - cargo clippy & cargo fmt ([`cf6fbbf`](https://github.comgit//apertus-open-source-cinema/narui/commit/cf6fbbf906beccd8ec9c3cd63c082c27897af4be))
    - fix examples ([`cf563d0`](https://github.comgit//apertus-open-source-cinema/narui/commit/cf563d066410b79102e0b4f424e1b5b086225c79))
    - rework lyon renderer ([`5f61394`](https://github.comgit//apertus-open-source-cinema/narui/commit/5f61394e6652d3b57793a0852861c7d489865c13))
    - more clippy ([`7bb8420`](https://github.comgit//apertus-open-source-cinema/narui/commit/7bb842005c4bd3f92f07d2d9fa2cd59cf47a84e7))
    - clippy v2 ([`a8b3e53`](https://github.comgit//apertus-open-source-cinema/narui/commit/a8b3e53cf3b67329743325b003a423cdb71f4ebc))
    - cargo fmt ([`2cb1eb0`](https://github.comgit//apertus-open-source-cinema/narui/commit/2cb1eb0f29b37e847c8740a21a8d2df7286a6b1f))
    - misc cleanup ([`62138dc`](https://github.comgit//apertus-open-source-cinema/narui/commit/62138dcaaab2d9ff0d70dc7dfbbd42c06838d73b))
    - optimize keys ([`8972a69`](https://github.comgit//apertus-open-source-cinema/narui/commit/8972a69de77ed7837d849c7c029910eab3486c56))
</details>

==> narui_widgets-0.1.1.crate: narui_widgets-0.1.1/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

## 0.1.1 (2021-12-13)

minor fixes for better compatibility

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release.
 - 0 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release narui_core v0.1.1, narui_widgets v0.1.1 ([`d0eb5a7`](https://github.comgit//apertus-open-source-cinema/narui/commit/d0eb5a7b0448750c848ae6e382048fb60c1790f6))
    - Adjusting changelogs prior to release of narui_core v0.1.1, narui_widgets v0.1.1 ([`7e51058`](https://github.comgit//apertus-open-source-cinema/narui/commit/7e51058be8960873da3d46b53d7ed99d5840d438))
    - upgrade vulcano-rs to 0.27.0 ([`a4ec9f9`](https://github.comgit//apertus-open-source-cinema/narui/commit/a4ec9f992b405a6b832045f581e06d9b41f80c71))
</details>

## 0.1.0 (2021-11-19)

Initial release!

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 31 commits contributed to the release over the course of 83 calendar days.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`ded0884`](https://github.comgit//apertus-open-source-cinema/narui/commit/ded08846593b06955d2413823f439a7436189eae))
    - Release rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`dc18edd`](https://github.comgit//apertus-open-source-cinema/narui/commit/dc18edd7b636abfd9815716d9a3b0d297f2179e9))
    - Release freelist v0.1.0, rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`5b90685`](https://github.comgit//apertus-open-source-cinema/narui/commit/5b9068543940621cf046f0dbd8d84cad0b9bfa3d))
    - Release freelist v0.1.0, rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`974b403`](https://github.comgit//apertus-open-source-cinema/narui/commit/974b40366ec6bcd43a6c32883f117b7ca45753d8))
    - Release freelist v0.1.0, rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`86eb164`](https://github.comgit//apertus-open-source-cinema/narui/commit/86eb1640fe543d25e0e8842181aac6e9b392fe63))
    - add metadata to Cargo.toml files ([`23cb406`](https://github.comgit//apertus-open-source-cinema/narui/commit/23cb406809d31613caa3457eaa983e81b349eab6))
    - upgrade vulkano rs to 0.26.0 ([`30a2797`](https://github.comgit//apertus-open-source-cinema/narui/commit/30a2797815ef0b1ca38e782a8387c816732de1a4))
    - Rework macro imports ([`99bffa7`](https://github.comgit//apertus-open-source-cinema/narui/commit/99bffa76b373f2191ee2e50d425642905708961d))
    - Implement subpasses ([`a60d2d6`](https://github.comgit//apertus-open-source-cinema/narui/commit/a60d2d66b18ce49a05ec3e6491592f04de2e6e39))
    - formal-function-parameter-attributes for defaults ([`cd29c94`](https://github.comgit//apertus-open-source-cinema/narui/commit/cd29c94eb1ee3de66a78acdd3fbc0014880bd648))
    - implement correct (render) sorting for text ([`1aa92c5`](https://github.comgit//apertus-open-source-cinema/narui/commit/1aa92c534b1ef55750e7002d84a1da81ab413fdc))
    - render lyon, text and rounded rect single pass ([`4ad6232`](https://github.comgit//apertus-open-source-cinema/narui/commit/4ad623252ed3c4bbeccdc74a7ecd6d6cf77981fa))
    - cleanup too verbose types in narui_widgets ([`5dc288e`](https://github.comgit//apertus-open-source-cinema/narui/commit/5dc288eafdbf0e89c629f0cb376564519b1f5b12))
    - refactoring ([`16f0955`](https://github.comgit//apertus-open-source-cinema/narui/commit/16f0955fc104936fc29627c6bb29567e73ebe664))
    - optimize rect a bit, bring back circle_bench to rect_leaf ([`be5b9a1`](https://github.comgit//apertus-open-source-cinema/narui/commit/be5b9a16ef2eb8cd664af98b8b31c28e8d5a7ed2))
    - fix stroked rects ([`f62f964`](https://github.comgit//apertus-open-source-cinema/narui/commit/f62f9648833cf0df76ab33de65574ce62b1e44be))
    - integrate external hook count into FragmentStore ([`91d395e`](https://github.comgit//apertus-open-source-cinema/narui/commit/91d395ea042ca5d58aa37c85e6483f284473205a))
    - widget updates ([`cfa94f4`](https://github.comgit//apertus-open-source-cinema/narui/commit/cfa94f4f1694d2d78b2aa1d0494fb7da07744915))
    - change ergonomics of rect and input ([`0d4c5dc`](https://github.comgit//apertus-open-source-cinema/narui/commit/0d4c5dc333c5fb2fa24d88cbd2342c6d2aecc154))
    - clippy + fmt ([`43c7710`](https://github.comgit//apertus-open-source-cinema/narui/commit/43c7710aa9b8bb07dd40de75b8b2343ad9f86d28))
    - rework fragments to be stored in a FreeList besides their args ([`4ff7e6d`](https://github.comgit//apertus-open-source-cinema/narui/commit/4ff7e6d1bef469e0517888aa86dc0c1b1a867fbb))
    - Add support for clipping ([`c8867dd`](https://github.comgit//apertus-open-source-cinema/narui/commit/c8867dd0bce4633ab487b2125c00d8d16d2521cb))
    - implement depth testing, rework stack ([`5eba0e0`](https://github.comgit//apertus-open-source-cinema/narui/commit/5eba0e08724975a5a6525c3c6183553a697df2a2))
    - cargo clippy & cargo fmt ([`cf6fbbf`](https://github.comgit//apertus-open-source-cinema/narui/commit/cf6fbbf906beccd8ec9c3cd63c082c27897af4be))
    - fix examples ([`cf563d0`](https://github.comgit//apertus-open-source-cinema/narui/commit/cf563d066410b79102e0b4f424e1b5b086225c79))
    - rework lyon renderer ([`5f61394`](https://github.comgit//apertus-open-source-cinema/narui/commit/5f61394e6652d3b57793a0852861c7d489865c13))
    - more clippy ([`7bb8420`](https://github.comgit//apertus-open-source-cinema/narui/commit/7bb842005c4bd3f92f07d2d9fa2cd59cf47a84e7))
    - clippy v2 ([`a8b3e53`](https://github.comgit//apertus-open-source-cinema/narui/commit/a8b3e53cf3b67329743325b003a423cdb71f4ebc))
    - cargo fmt ([`2cb1eb0`](https://github.comgit//apertus-open-source-cinema/narui/commit/2cb1eb0f29b37e847c8740a21a8d2df7286a6b1f))
    - misc cleanup ([`62138dc`](https://github.comgit//apertus-open-source-cinema/narui/commit/62138dcaaab2d9ff0d70dc7dfbbd42c06838d73b))
    - optimize keys ([`8972a69`](https://github.comgit//apertus-open-source-cinema/narui/commit/8972a69de77ed7837d849c7c029910eab3486c56))
</details>
